Trait Command
pub trait Command {
// Required method
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>;
}Available on crate feature
term only.Expand description
An interface for a command that performs an action on the terminal.
Crossterm provides a set of commands, and there is no immediate reason to implement a command yourself. In order to understand how to use and execute commands, it is recommended that you take a look at Command API chapter.
Required Methods
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
Write an ANSI representation of this command to the given writer. An ANSI code can manipulate the terminal by writing it to the terminal buffer. However, only Windows 10 and UNIX systems support this.
This method does not need to be accessed manually, as it is used by the crossterm’s Command API
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Implementors
impl Command for BeginSynchronizedUpdate
impl Command for Clear
impl Command for DisableBlinking
impl Command for DisableBracketedPaste
Available on crate feature
bracketed-paste only.impl Command for DisableFocusChange
impl Command for DisableLineWrap
impl Command for DisableMouseCapture
impl Command for EnableBlinking
impl Command for EnableBracketedPaste
Available on crate feature
bracketed-paste only.impl Command for EnableFocusChange
impl Command for EnableLineWrap
impl Command for EnableMouseCapture
Available on crate feature
events only.