Commands

Trait Commands 

pub trait Commands {
    // Required method
    fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>;
}
Available on crate feature term only.
An ordered batch of terminal commands.

Implemented for borrowed collections that yield shared Command references and for heterogeneous tuples of up to 20 commands.

Required Methods

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Writes the ANSI representation of every command in order.

This method is normally called through CommandQueue::queue_many.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Commands for ()

Source

fn write_ansi(&self, _: &mut impl Write) -> Result<(), Error>

Source

impl<'a, C, I> Commands for &'a I
where C: Command + 'a, &'a I: IntoIterator<Item = &'a C>, I: ?Sized,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C0, C1, C2, C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C0: Command, C1: Command, C2: Command, C3: Command, C4: Command, C5: Command, C6: Command, C7: Command, C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C1, C2, C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C1, C2, C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C1: Command, C2: Command, C3: Command, C4: Command, C5: Command, C6: Command, C7: Command, C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C2, C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C2, C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C2: Command, C3: Command, C4: Command, C5: Command, C6: Command, C7: Command, C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C3: Command, C4: Command, C5: Command, C6: Command, C7: Command, C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C4, C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C4: Command, C5: Command, C6: Command, C7: Command, C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C5, C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C5: Command, C6: Command, C7: Command, C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C6, C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C6: Command, C7: Command, C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C7, C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C7: Command, C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C8, C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C8: Command, C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C9, C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C9: Command, C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C10, C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C10, C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C10: Command, C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C11, C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C11, C12, C13, C14, C15, C16, C17, C18, C19)
where C11: Command, C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C12, C13, C14, C15, C16, C17, C18, C19> Commands for (C12, C13, C14, C15, C16, C17, C18, C19)
where C12: Command, C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C13, C14, C15, C16, C17, C18, C19> Commands for (C13, C14, C15, C16, C17, C18, C19)
where C13: Command, C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C14, C15, C16, C17, C18, C19> Commands for (C14, C15, C16, C17, C18, C19)
where C14: Command, C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C15, C16, C17, C18, C19> Commands for (C15, C16, C17, C18, C19)
where C15: Command, C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C16, C17, C18, C19> Commands for (C16, C17, C18, C19)
where C16: Command, C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C17, C18, C19> Commands for (C17, C18, C19)
where C17: Command, C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C18, C19> Commands for (C18, C19)
where C18: Command, C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Source

impl<C19> Commands for (C19,)
where C19: Command,

Source

fn write_ansi(&self, writer: &mut impl Write) -> Result<(), Error>

Implementors